import { Options as Options$1, ExecaReturnValue } from 'execa';

type Options = Partial<{
    help: boolean;
    version: boolean;
    verbose: boolean;
    init: boolean | string;
    config: string;
    workdir: string;
    repository: string;
    includePath: string;
    excludePath: string;
    withCommit: string;
    skipCommit: string;
    prepend: string;
    output: string;
    tag: string;
    bump: boolean;
    bumpedVersion: boolean;
    body: string;
    latest: boolean;
    current: boolean;
    unreleased: boolean;
    topoOrder: boolean;
    noExec: boolean;
    context: boolean;
    strip: "header" | "footer" | "all";
    sort: "oldest" | "newest";
    githubToken: string;
    githubRepo: string;
}>;

/**
 * Runs `git-cliff` with the provided options as a JavaScript object.
 *
 * @param options - The options to pass to `git-cliff`.
 * These get transformed into an array strings.
 * - Values that are `true` will be passed as flags (`--flag`).
 * - Values that are `false` or `null` will be ignored.
 * - All other values will be passed as options (`--option value`).
 *
 * @param execaOptions - Options to pass to {@link execa}.
 */
declare function runGitCliff(options: Options, execaOptions?: Options$1): Promise<ExecaReturnValue<string>>;
/**
 * Runs the `git-cliff` with the provided arguments.
 *
 * @param args - The arguments to pass to `git-cliff`.
 * These should be in an array of string format.
 * Every option and their value should be its own entry in the array.
 *
 * @param execaOptions - Options to pass to {@link execa}.
 *
 * @returns A promise that resolves when the `git-cliff` has finished running.
 *
 * @example
 * Options with values
 * ```typescript
 * await runGitCliff(["--tag", "1.0.0", "--config", "github"]);
 * ```
 *
 * @example
 * Boolean flags
 * ```typescript
 * await runGitCliff(["--unreleased", "--topo-order"]);
 * ```
 *
 * @example
 * Combining options and flags
 * ```typescript
 * await runGitCliff(["--tag", "1.0.0", "--config", "github", "--topo-order"]);
 * ```
 */
declare function runGitCliff(args: string[], execaOptions?: Options$1): Promise<ExecaReturnValue<string>>;

export { type Options, runGitCliff };
